==> data_prep_toolkit-0.0.1.dev12.tar.gz: data_prep_toolkit-0.0.1.dev12/test/data_processing_tests/launch/pure_python/launcher_test.py <==
# (C) Copyright IBM Corp. 2024.
# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
################################################################################

import os
import sys

from data_processing.runtime.pure_python import (
    PythonLauncherConfiguration,
    PythonTransformLauncher,
)
from data_processing.transform import AbstractTableTransform, TransformConfiguration
from data_processing.utils import ParamsUtils


"""
 see: https://stackoverflow.com/questions/55259371/pytest-testing-parser-error-unrecognised-arguments
 to run test using argparse we can simply overwrite sys.argv to supply required arguments
"""
s3_cred = {
    "access_key": "access",
    "secret_key": "secret",
    "url": "https://s3.us-east.cloud-object-storage.appdomain.cloud",
}
s3_conf = {
    "input_folder": "input_folder",
    "output_folder": "output_folder",
}
local_conf = {
    "input_folder": os.path.join(os.sep, "tmp", "input"),
    "output_folder": os.path.join(os.sep, "tmp", "output"),
}

code_location = {"github": "github", "commit_hash": "12345", "path": "path"}


class TestingTransformConfiguration(TransformConfiguration):
    def __init__(self):
        super().__init__("test", transform_class=AbstractTableTransform)


class TestLauncherPython(PythonTransformLauncher):
    """
    Test driver for validation of the functionality
    """

    def __init__(self):
        super().__init__(TestingTransformConfiguration())

    def _submit_for_execution(self) -> int:
        """
        Overwrite this method to just print all parameters to make sure that everything works
        :return:
        """
        print("\n\nPrinting preprocessing parameters")
        return 0


def test_launcher():
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # s3 not defined
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res
    # Add S3 configuration
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    # Add S3 credentials
    params["data_s3_cred"] = ParamsUtils.convert_to_ast(s3_cred)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res
    # Add local config, should fail because now three different configs exist
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    # remove local config, should still fail, because two configs left
    del params["data_local_config"]
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_local_config():
    # test that the driver works with local configuration
    params = {
        "data_local_config": ParamsUtils.convert_to_ast(local_conf),
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_local_config_validate():
    # test the validation of the local configuration
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # invalid local configurations, driver launch should fail with any of these
    local_conf_empty = {}
    local_conf_no_input = {"output_folder": "output_folder"}
    local_conf_no_output = {"input_folder": "input_folder"}
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_empty)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    print(f"parameters {sys.argv}")
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_no_input)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_no_output)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_s3_config_validate():
    # test the validation of the local configuration
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "data_s3_cred": ParamsUtils.convert_to_ast(s3_cred),
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # invalid local configurations, driver launch should fail with any of these
    s3_conf_empty = {}
    s3_conf_no_input = {"output_folder": "output_folder"}
    s3_conf_no_output = {"input_folder": "input_folder"}
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_empty)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    print(f"parameters {sys.argv}")
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_no_input)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_no_output)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res

==> data_prep_toolkit-0.1.0.tar.gz: data_prep_toolkit-0.1.0/test/data_processing_tests/launch/pure_python/launcher_test.py <==
# (C) Copyright IBM Corp. 2024.
# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
################################################################################

import os
import sys

from data_processing.runtime.pure_python import PythonTransformLauncher
from data_processing.test_support.transform import NOOPPythonTransformConfiguration
from data_processing.utils import ParamsUtils


"""
 see: https://stackoverflow.com/questions/55259371/pytest-testing-parser-error-unrecognised-arguments
 to run test using argparse we can simply overwrite sys.argv to supply required arguments
"""
s3_cred = {
    "access_key": "access",
    "secret_key": "secret",
    "url": "https://s3.us-east.cloud-object-storage.appdomain.cloud",
}
s3_conf = {
    "input_folder": "input_folder",
    "output_folder": "output_folder",
}
local_conf = {
    "input_folder": os.path.join(os.sep, "tmp", "input"),
    "output_folder": os.path.join(os.sep, "tmp", "output"),
}

code_location = {"github": "github", "commit_hash": "12345", "path": "path"}


class TestLauncherPython(PythonTransformLauncher):
    """
    Test driver for validation of the functionality
    """

    def __init__(self):
        super().__init__(NOOPPythonTransformConfiguration())

    def _submit_for_execution(self) -> int:
        """
        Overwrite this method to just print all parameters to make sure that everything works
        :return:
        """
        return 0


def test_launcher():
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # s3 not defined
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res
    # Add S3 configuration
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    # Add S3 credentials
    params["data_s3_cred"] = ParamsUtils.convert_to_ast(s3_cred)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res
    # Add local config, should fail because now three different configs exist
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    # remove local config, should still fail, because two configs left
    del params["data_local_config"]
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_local_config():
    # test that the driver works with local configuration
    params = {
        "data_local_config": ParamsUtils.convert_to_ast(local_conf),
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_local_config_validate():
    # test the validation of the local configuration
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # invalid local configurations, driver launch should fail with any of these
    local_conf_empty = {}
    local_conf_no_input = {"output_folder": "output_folder"}
    local_conf_no_output = {"input_folder": "input_folder"}
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_empty)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    print(f"parameters {sys.argv}")
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_no_input)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf_no_output)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_local_config"] = ParamsUtils.convert_to_ast(local_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res


def test_s3_config_validate():
    # test the validation of the local configuration
    params = {
        "data_max_files": -1,
        "data_checkpointing": False,
        "data_s3_cred": ParamsUtils.convert_to_ast(s3_cred),
        "runtime_pipeline_id": "pipeline_id",
        "runtime_job_id": "job_id",
        "runtime_code_location": ParamsUtils.convert_to_ast(code_location),
    }
    # invalid local configurations, driver launch should fail with any of these
    s3_conf_empty = {}
    s3_conf_no_input = {"output_folder": "output_folder"}
    s3_conf_no_output = {"input_folder": "input_folder"}
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_empty)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    print(f"parameters {sys.argv}")
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_no_input)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf_no_output)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 1 == res
    params["data_s3_config"] = ParamsUtils.convert_to_ast(s3_conf)
    sys.argv = ParamsUtils.dict_to_req(d=params)
    res = TestLauncherPython().launch()
    assert 0 == res
